package org.rcisoft.bus.jnsp7xtm.service.impl;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.bus.jnsp7xtm.dao.Jnsp7xtmStatisticsRepository;
import org.rcisoft.bus.jnsp7xtm.dto.*;
import org.rcisoft.bus.jnsp7xtm.entity.Jnsp7xtm;
import org.rcisoft.bus.jnsp7xtm.enums.ColTransitionEnum;
import org.rcisoft.bus.jnsp7xtm.service.Jnsp7xtmStatisticService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @Author: gy
 * @Date: 2024/5/7 11:28
 * @Description:
 */
@Slf4j
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
public class Jnsp7xtmStatisticServiceImpl implements Jnsp7xtmStatisticService {

    @Autowired
    private Jnsp7xtmStatisticsRepository jnsp74tmStatisticsRepository;

    //  1.查询所有下拉框数据源
    @Override
    public List<Jnsp7xtmOptionDto> queryAllPullDownData(Jnsp7xtmPageRequestDto jnsp74tmPageRequestDto) {
        List<Jnsp7xtmOptionDto> dataList = new ArrayList<>();
        // 1.获取khdm
        List<String> khdm = jnsp74tmStatisticsRepository.queryAllPullDown("khdm");
        Jnsp7xtmOptionDto khdmPullDowmData = Jnsp7xtmOptionDto.builder().label("khdm").pullDownList(khdm).build();
        dataList.add(khdmPullDowmData);
        // 2.获取Khm
        List<String> khm = jnsp74tmStatisticsRepository.queryAllPullDown("khm");
        dataList.add(Jnsp7xtmOptionDto.builder().label("Khm").pullDownList(khm).build());
        // 3.获取pn
        List<String> pn = jnsp74tmStatisticsRepository.queryAllPullDown("pn");
        dataList.add(Jnsp7xtmOptionDto.builder().label("pn").pullDownList(pn).build());
        // 4.获取jlpm
        List<String> jlpm = jnsp74tmStatisticsRepository.queryAllPullDown("jlpm");
        dataList.add(Jnsp7xtmOptionDto.builder().label("jlpm").pullDownList(jlpm).build());
        // 5.获取zd
        List<String> zd = jnsp74tmStatisticsRepository.queryAllPullDown("zd");
        dataList.add(Jnsp7xtmOptionDto.builder().label("zd").pullDownList(zd).build());
        // 6.获取fnq
        List<String> fnq = jnsp74tmStatisticsRepository.queryAllPullDown("fnq");
        dataList.add(Jnsp7xtmOptionDto.builder().label("fnq").pullDownList(fnq).build());
        // 7.获取szzt
        List<String> szzt = jnsp74tmStatisticsRepository.queryAllPullDown("szzt");
        dataList.add(Jnsp7xtmOptionDto.builder().label("szzt").pullDownList(szzt).build());
        // 8.获取mksqf
        List<String> mksqf = jnsp74tmStatisticsRepository.queryAllPullDown("mksqf");
        dataList.add(Jnsp7xtmOptionDto.builder().label("mksqf").pullDownList(mksqf).build());
        return dataList;
    }

    // 2.实时查询下拉框数据
    @Override
    public List<Jnsp7xtm> queryKey(Jnsp7xtm Jnsp74tm) {
        return jnsp74tmStatisticsRepository.queryKey(Jnsp74tm);
    }

    // 3.查询统计
    @Override
    public Jnsp7xtmPageListDto getPageList(Jnsp7xtmPageRequestDto jnsp74tmPageRequestDto) {
        // 前置查询条件
        boolean conditionIsNull =
                jnsp74tmPageRequestDto.isRmb() ||
                        jnsp74tmPageRequestDto.isXsjg() ||
                        jnsp74tmPageRequestDto.isCount() || jnsp74tmPageRequestDto.isChzs() || jnsp74tmPageRequestDto.isChzsa() || jnsp74tmPageRequestDto.isChzsb() || jnsp74tmPageRequestDto.isZzc() || jnsp74tmPageRequestDto.isZzcg();
        //没有选择默认选一个
        if (!conditionIsNull) {
            jnsp74tmPageRequestDto.setChzs(true);
        }
        //查询月份
        List<String> monthsList = jnsp74tmStatisticsRepository.getMonths();

        String months = monthsList.stream()
                .map(month -> "[" + month + "]")
                .collect(Collectors.joining(","));

        Jnsp7xtmPageListDto jnsp74tmPageListDto = new Jnsp7xtmPageListDto();
        if (!StringUtils.isNotBlank(jnsp74tmPageRequestDto.getOneDimensionality()) && !StringUtils.isNotBlank(jnsp74tmPageRequestDto.getTwoDimensionality()) && !StringUtils.isNotBlank(jnsp74tmPageRequestDto.getThreeDimensionality())) {
            jnsp74tmPageRequestDto.setOneDimensionality(ColTransitionEnum.JNSP7XTM.getCode() + "khdm");
            jnsp74tmPageRequestDto.setTwoDimensionality(ColTransitionEnum.JNSP7XTM.getCode() + "khm");
        }
        // 获取统计列
        String  statistics = "";
        // 获取排序列
        String orderColumn = "";
        // 获取关联表语句
        List<String> joinSqlList = new ArrayList<>();

        String joinSql = "";

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getOneDimensionality())) {
            String statisticsOneOneDimensionality = "";
            String orderOneOneDimensionality = "";
            if (jnsp74tmPageRequestDto.getOneDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getOneDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), ColTransitionEnum.JNSP7XTM.getValue());
                orderOneOneDimensionality = jnsp74tmPageRequestDto.getOneDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), "");
            }

            if (jnsp74tmPageRequestDto.getOneDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getOneDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), ColTransitionEnum.CUSTOMER.getValue());
                orderOneOneDimensionality = jnsp74tmPageRequestDto.getOneDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
                joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
            }
            statistics = statisticsOneOneDimensionality;
            orderColumn = orderOneOneDimensionality;
        }

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getTwoDimensionality())) {
            String statisticsOneOneDimensionality = "";
            String orderOneOneDimensionality = "";
            if (!"".equals(statistics)) {
                if (jnsp74tmPageRequestDto.getTwoDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), ColTransitionEnum.JNSP7XTM.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), "");
                }
                if (jnsp74tmPageRequestDto.getTwoDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), ColTransitionEnum.CUSTOMER.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
                    joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
                }
                statistics = statistics +","+ statisticsOneOneDimensionality;
                orderColumn = orderColumn + "," + orderOneOneDimensionality;
            } else {

                if (jnsp74tmPageRequestDto.getTwoDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), ColTransitionEnum.JNSP7XTM.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), "");
                }

                if (jnsp74tmPageRequestDto.getTwoDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), ColTransitionEnum.CUSTOMER.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
                    joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
                }
                statistics = statisticsOneOneDimensionality;
                orderColumn = orderOneOneDimensionality;
            }
        }

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getThreeDimensionality())) {
            String statisticsOneOneDimensionality = "";
            String orderOneOneDimensionality = "";
            if (!"".equals(statistics)) {
                if (jnsp74tmPageRequestDto.getThreeDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(),ColTransitionEnum.JNSP7XTM.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(),"");
                }

                if (jnsp74tmPageRequestDto.getThreeDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), ColTransitionEnum.CUSTOMER.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
                    joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
                }
                statistics = statistics + ","+ statisticsOneOneDimensionality;
                orderColumn = orderColumn + "," +orderOneOneDimensionality;
            } else {
                if (jnsp74tmPageRequestDto.getThreeDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(),ColTransitionEnum.JNSP7XTM.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(),"");
                }
                if (jnsp74tmPageRequestDto.getThreeDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                    statisticsOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), ColTransitionEnum.CUSTOMER.getValue());
                    orderOneOneDimensionality = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
                    joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
                }
                statistics = statisticsOneOneDimensionality;
                orderColumn = orderOneOneDimensionality;
            }
        }
        if (!joinSqlList.isEmpty()) {
            joinSql = joinSqlList.stream().distinct().collect(Collectors.joining(" "));
        }


        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getKhdm())) {
            jnsp74tmPageRequestDto.setVagueKhdm("");
        }
        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getKhm())) {
            jnsp74tmPageRequestDto.setVaguekhm("");
        }
        List<Map<String, Object>> maps = jnsp74tmStatisticsRepository.queryStatisticsCount(jnsp74tmPageRequestDto, months,statistics,orderColumn,joinSql);
        jnsp74tmPageListDto.setTotal(maps.size());

        // 获取list
        List<Jnsp7xtmPageDto> list = getList(jnsp74tmPageRequestDto, months, monthsList,statistics,orderColumn,joinSql);
        jnsp74tmPageListDto.setUserDtoList(list);
        return jnsp74tmPageListDto;
    }

    // 4.返回总计接口
    @Override
    public Jnsp7xtmTotalDto queryTotal(Jnsp7xtmPageRequestDto jnsp74tmPageRequestDto) {
        Jnsp7xtmTotalDto jnsp74tmTotalDto = new Jnsp7xtmTotalDto();
        // 前置查询条件
        boolean conditionIsNull =
                jnsp74tmPageRequestDto.isRmb() ||
                        jnsp74tmPageRequestDto.isXsjg() ||
                        jnsp74tmPageRequestDto.isCount() || jnsp74tmPageRequestDto.isChzs() || jnsp74tmPageRequestDto.isChzsa() || jnsp74tmPageRequestDto.isChzsb() || jnsp74tmPageRequestDto.isZzc() || jnsp74tmPageRequestDto.isZzcg();
        //没有选择默认选一个
        if (!conditionIsNull) {
            jnsp74tmPageRequestDto.setChzs(true);
        }
        //查询月份
        List<String> monthsList = jnsp74tmStatisticsRepository.getMonths();
        String months = monthsList.stream().collect(Collectors.joining(","));
        if (!StringUtils.isNotBlank(jnsp74tmPageRequestDto.getNqy())) {
            jnsp74tmPageRequestDto.setNqy(months);
        }
        // 设置空Jnsp74tm
        Jnsp7xtmDto jnsp74TmDto = getEmptyJnsp74xmDto(jnsp74tmPageRequestDto);
        // 根据条件查询数据每个年份对应的合计值
        // 获取关联表语句
        List<String> joinSqlList = new ArrayList<>();
        String joinSql = "";
        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getOneDimensionality())) {
            if (jnsp74tmPageRequestDto.getOneDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
            }
        }

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getTwoDimensionalityValue())) {
            if (jnsp74tmPageRequestDto.getTwoDimensionalityValue().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
            }
        }

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getThreeDimensionalityValue())) {
            if (jnsp74tmPageRequestDto.getThreeDimensionalityValue().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                joinSqlList.add("left join b_customer cust on cust.cust_code = j7xtm.khdm and cust.del_flag = '0'");
            }
        }
        if (!joinSqlList.isEmpty()) {
            joinSql = joinSqlList.stream().distinct().collect(Collectors.joining(" "));
        }
        jnsp74tmPageRequestDto.setJoinSql(joinSql);
        List<Jnsp7xtmDto> jnsp74TmDtoList = jnsp74tmStatisticsRepository.queryTotal(jnsp74tmPageRequestDto);
        if (!jnsp74TmDtoList.isEmpty()) {
            // 过滤出没有对应合计值年份
            List<String> filteredList = monthsList.stream()
                    .filter(month -> !jnsp74TmDtoList.stream().map(Jnsp7xtmDto::getNqy).collect(Collectors.toList()).contains(month))
                    .collect(Collectors.toList());
            if (!filteredList.isEmpty()) {
                for (int i = 0; i < filteredList.size(); i++) {
                    Jnsp7xtmDto one = new Jnsp7xtmDto();
                    BeanUtils.copyProperties(jnsp74TmDto, one);
                    one.setNqy(filteredList.get(i));
                    jnsp74TmDtoList.add(one);
                }
            }
        }
        List<Jnsp7xtmDto> collect = jnsp74TmDtoList.stream().sorted(Comparator.comparing(Jnsp7xtmDto::getNqy)).collect(Collectors.toList());
        jnsp74tmTotalDto.setJnsp7xtmDtos(collect);
        return jnsp74tmTotalDto;
    }


    // 获取统计的list
    private List<Jnsp7xtmPageDto> getList(Jnsp7xtmPageRequestDto jnsp74tmPageRequestDto, String months, List<String> monthsList, String statistics,String orderColumn,String joinSql) {
        // 初始化 listrmb 和 listxsjg 的值
        List<Map<String,Object>> listrmb = null;
        List<Map<String,Object>> listxsjg = null;
        List<Map<String,Object>> listChzs = null;
        List<Map<String,Object>> listChzsA = null;
        List<Map<String,Object>> listChzsB = null;
        List<Map<String,Object>> listzzc = null;
        List<Map<String,Object>> listzzcg = null;
        //页数
        Integer pageNo = jnsp74tmPageRequestDto.getPageNo();
        //每页大小
        Integer pageSize = jnsp74tmPageRequestDto.getPageSize();
        boolean[] flag = new boolean[]{jnsp74tmPageRequestDto.isXsjg(), jnsp74tmPageRequestDto.isRmb(), jnsp74tmPageRequestDto.isChzs(), jnsp74tmPageRequestDto.isChzsa(), jnsp74tmPageRequestDto.isChzsb(), jnsp74tmPageRequestDto.isZzc(), jnsp74tmPageRequestDto.isZzcg()};
        if (jnsp74tmPageRequestDto.isXsjg())
            listxsjg = jnsp74tmStatisticsRepository.queryList(jnsp74tmPageRequestDto,months,pageNo,pageSize,"1","j7xtm.xsjg",statistics,orderColumn,joinSql);
        if (jnsp74tmPageRequestDto.isRmb())
            listrmb = jnsp74tmStatisticsRepository.queryList(jnsp74tmPageRequestDto,months,pageNo,pageSize,"1","j7xtm.rmb",statistics,orderColumn,joinSql);
        if (jnsp74tmPageRequestDto.isChzs())
            listChzs = jnsp74tmStatisticsRepository.queryList(jnsp74tmPageRequestDto,months,pageNo,pageSize,"1","j7xtm.chzsa+j7xtm.chzsb",statistics,orderColumn,joinSql);

        if (jnsp74tmPageRequestDto.isChzsa())
            listChzsA = jnsp74tmStatisticsRepository.queryList(jnsp74tmPageRequestDto,months,pageNo,pageSize,"1","j7xtm.chzsa",statistics,orderColumn,joinSql);

        if (jnsp74tmPageRequestDto.isChzsb())
            listChzsB = jnsp74tmStatisticsRepository.queryList(jnsp74tmPageRequestDto,months,pageNo,pageSize,"1","j7xtm.chzsb",statistics,orderColumn,joinSql);

        if (jnsp74tmPageRequestDto.isZzc())
            listzzc = jnsp74tmStatisticsRepository.queryList(jnsp74tmPageRequestDto,months,pageNo,pageSize,"1","j7xtm.zzc",statistics,orderColumn,joinSql);
        if (jnsp74tmPageRequestDto.isZzcg())
            listzzcg = jnsp74tmStatisticsRepository.queryList(jnsp74tmPageRequestDto,months,pageNo,pageSize,"1","j7xtm.zzcg",statistics,orderColumn,joinSql);
        //获取对应关系
        Map<String, Jnsp7xtmPageDto> map = new HashMap();
        //创建填充数据
        List<Jnsp7xtmPageDto> resList = new ArrayList<>();
        //获取日期参数
        List<String> nqy = new ArrayList<>();
        //判断是否传入日期参数，如果没传入设置默认值
        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getNqy())) {
            nqy = Arrays.stream(StringUtils.split(jnsp74tmPageRequestDto.getNqy(), ',')).toList();
        } else {
            nqy = monthsList;
        }

        int size = 0;
        //获得返回数据长度

        if (listrmb != null) {
            size = listrmb.size();
        } else if (listxsjg != null) {
            size = listxsjg.size();
        } else if (listChzs != null) {
            size = listChzs.size();
        } else if (listChzsA != null) {
            size = listChzsA.size();
        } else if (listChzsB != null) {
            size = listChzsB.size();
        } else if (listzzc != null) {
            size = listzzc.size();
        } else if (listzzcg != null) {
            size = listzzcg.size();
        }

        /**
         * 1)
         *listChzs[{khdm = 00019200,202406=20.000,202407=110.00,202402=30.000,202403=235.000}]
         *listChA[{khdm = 00019200,202406=20.000,202407=110.00,202402=30.000,202403=235.000}]
         *
         */

        for (int i = 0; i < size; i++) {

            if (listChzs != null) {
                getObjectByMap(listChzs, i, map, nqy, flag, resList, "CHZS", jnsp74tmPageRequestDto);
            }
            /**
             * 2)
             * listrmb : [{A:,B:}]
             * listzzcg: []
             */

            //填充三种数据
            if (listrmb != null) {
                getObjectByMap(listrmb, i, map, nqy, flag, resList, "RMB", jnsp74tmPageRequestDto);
            }
            if (listxsjg != null) {
                getObjectByMap(listxsjg, i, map, nqy, flag, resList, "XSJG", jnsp74tmPageRequestDto);
            }
            if (listChzsA != null) {
                getObjectByMap(listChzsA, i, map, nqy, flag, resList, "CHZSA", jnsp74tmPageRequestDto);
            }
            if (listChzsB != null) {
                getObjectByMap(listChzsB, i, map, nqy, flag, resList, "CHZSB", jnsp74tmPageRequestDto);
            }
            if (listzzc != null) {
                getObjectByMap(listzzc, i, map, nqy, flag, resList, "ZZC", jnsp74tmPageRequestDto);
            }
            if (listzzcg != null) {
                getObjectByMap(listzzcg, i, map, nqy, flag, resList, "ZZCG", jnsp74tmPageRequestDto);
            }

        }
        return resList;
    }

    private void getObjectByMap(List<Map<String,Object>> listrmb, int i, Map<String, Jnsp7xtmPageDto> map, List<String> nqy, boolean[] flag, List<Jnsp7xtmPageDto> resList, String tar, Jnsp7xtmPageRequestDto jnsp74tmPageRequestDto) {
        Map listMap = listrmb.get(i);
        String key = "";
        // 维度一
        String dimensionalityOne = "";
        // 维度二
        String dimensionalityTwo = "";
        // 维度三
        String dimensionalityThree = "";

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getOneDimensionality())) {
            String originalOneDime = "";
            if (jnsp74tmPageRequestDto.getOneDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                originalOneDime = jnsp74tmPageRequestDto.getOneDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), "");
            }
            if (jnsp74tmPageRequestDto.getOneDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())){
                originalOneDime = jnsp74tmPageRequestDto.getOneDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
            }

            if (listMap.containsKey(originalOneDime)) {
                key = key + listMap.get(originalOneDime) + "::";
                dimensionalityOne = (String) listMap.get(originalOneDime);
                listMap.remove(originalOneDime);
            }
        }

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getTwoDimensionality())) {
            String originalTwoDime = "";
            if (jnsp74tmPageRequestDto.getTwoDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                originalTwoDime = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), "");
            }
            if (jnsp74tmPageRequestDto.getTwoDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                originalTwoDime = jnsp74tmPageRequestDto.getTwoDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
            }
            if (listMap.containsKey(originalTwoDime)) {
                key = key + listMap.get(originalTwoDime) + "::";
                dimensionalityTwo = (String) listMap.get(originalTwoDime);
                listMap.remove(originalTwoDime);
            }
        }

        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getThreeDimensionality())) {
            String originalthreeDime = "";
            if (jnsp74tmPageRequestDto.getThreeDimensionality().contains(ColTransitionEnum.JNSP7XTM.getCode())) {
                originalthreeDime = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.JNSP7XTM.getCode(), "");
            }

            if (jnsp74tmPageRequestDto.getThreeDimensionality().contains(ColTransitionEnum.CUSTOMER.getCode())) {
                originalthreeDime = jnsp74tmPageRequestDto.getThreeDimensionality().replace(ColTransitionEnum.CUSTOMER.getCode(), "");
            }
            if (listMap.containsKey(originalthreeDime)) {
                key = key + listMap.get(originalthreeDime) + "::";
                dimensionalityThree = (String) listMap.get(originalthreeDime);
                listMap.remove(originalthreeDime);
            }
        }
        /**
         * userDto null
         * **/
        Jnsp7xtmPageDto userDto = map.getOrDefault(key, null);
        //判断该用户是否创建过
        if (userDto == null) {
            //创建对象加入到list结果中
            userDto = new Jnsp7xtmPageDto(dimensionalityOne, dimensionalityTwo, dimensionalityThree, nqy, flag);
            /**
             * resList = [{dimensionalityOne = '00019200',dimensionalityTwo = '',dimensionalityThree = '',data:[{nqy=202402,chzs=''},{nqy=202403,chzs=''},{nqy=202404,chzs=''},{nqy=202406,chzs=''},{nqy=202407,chzs=''}]},data2 = null,map = {202402 = 0,202403 = 1,202404 = 2,202406 = 3,202407 = 4 }]
             * map key值年份 value是对应的下坐标
             * **/
            resList.add(userDto);
            /**
             * map = {00019200 = {dimensionalityOne = '00019200',dimensionalityTwo = '',dimensionalityThree = '',data:[{nqy=202402,chzs=''},{nqy=202403,chzs=''},{nqy=202404,chzs=''},{nqy=202406,chzs=''},{nqy=202407,chzs=''}]},data2 = null,map = {202402 = 0,202403 = 1,202404 = 2,202406 = 3,202407 = 4 }}
             *
             * **/
            map.put(key.toString(), userDto);
        }
        //获取到user中的Data数据
        /**
         * data: [{nqy=202402,chzs=''},{nqy=202403,chzs=''},{nqy=202404,chzs=''},{nqy=202406,chzs=''},{nqy=202407,chzs=''}]
         * **/
        List<Jnsp7xtmDto> data = userDto.getData();
        //获取月份对照集合
        /**
         * month: [{202402 = 0,202403 = 1,202404 = 2,202406 = 3,202407 = 4 }]
         * ***/
        Map<String, Integer> month = userDto.getMap();
        //set为键值对对象
        /**
         * set = [202402  = 30.000,202403 = 235.000,202406 = 20.000,202407 = 110.000]
         * **/
        Set set = listMap.entrySet();
        for (Object o : set) {

            //强制转化为Entry对象
            Map.Entry<String, String> entry = (Map.Entry<String, String>) o;

            //获取到数据库中对应的月份
            String target = listMap.getOrDefault(entry.getKey(), null).toString();
            //不为空添加数据
            if (target != null) {
                //获取月份对应的下标
                Integer index = month.get(entry.getKey());
                //获取信息
                Jnsp7xtmDto jnsp7XtmDto = data.get(index);
                //原则上调用toString方法能解决，但是JIT自动优化了，只能使用上转型
                Object value = entry.getValue();
                if (tar.equals("CHZS")) {
                    jnsp7XtmDto.setChzs(String.valueOf(value));
                }
                if (tar.equals("RMB")) {
                    jnsp7XtmDto.setRmb(String.valueOf(value));
                }
                if (tar.equals("XSJG")) {
                    jnsp7XtmDto.setXsjg(String.valueOf(value));
                }
                if (tar.equals("CHZSA")) {
                    jnsp7XtmDto.setChzsa(String.valueOf(value));
                }
                if (tar.equals("CHZSB")) {
                    jnsp7XtmDto.setChzsb(String.valueOf(value));
                }
                if (tar.equals("ZZC")) {
                    jnsp7XtmDto.setZzc(String.valueOf(value));
                }
                if (tar.equals("ZZCG")) {
                    jnsp7XtmDto.setZzcg(String.valueOf(value));
                }
            }
        }
    }

    public Jnsp7xtmDto getEmptyJnsp74xmDto(Jnsp7xtmPageRequestDto jnsp74tmPageRequestDto) {
        Jnsp7xtmDto jnsp74TmDto = new Jnsp7xtmDto();
        if (jnsp74tmPageRequestDto.isXsjg()) {
            jnsp74TmDto.setXsjg("");
        }
        if (jnsp74tmPageRequestDto.isRmb()) {
            jnsp74TmDto.setRmb("");
        }
        if (jnsp74tmPageRequestDto.isChzs()) {
            jnsp74TmDto.setChzs("");
        }
        if (jnsp74tmPageRequestDto.isChzsa()) {
            jnsp74TmDto.setChzsa("");
        }
        if (jnsp74tmPageRequestDto.isChzsb()) {
            jnsp74TmDto.setChzsb("");
        }
        if (jnsp74tmPageRequestDto.isZzc()) {
            jnsp74TmDto.setZzc("");
        }
        if (jnsp74tmPageRequestDto.isZzcg()) {
            jnsp74TmDto.setZzcg("");
        }
        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getKhdm())) {
            jnsp74tmPageRequestDto.setVagueKhdm("");
        }
        if (StringUtils.isNotBlank(jnsp74tmPageRequestDto.getKhm())) {
            jnsp74tmPageRequestDto.setVaguekhm("");
        }
        return jnsp74TmDto;
    }

}
